# -*- coding: utf-8 -*-
"""This is the pypingdom package."""

from __future__ import absolute_import
from pypingdom.client import Client  # noqa: F401
from pypingdom.check import Check  # noqa: F401
from pypingdom.maintenance import Maintenance  # noqa: F401

__author__ = 'Paolo Sechi <sekipaolo@gmail.com>'
__license__ = "Apache v2.0"
